@@ -63,11 +63,17 @@ public:
   virtual VPlacedVolume const *ConvertToUnspecialized() const override;
 
 #ifdef VECGEOM_ROOT
-  virtual TGeoShape const *ConvertToRoot() const override;
+  virtual TGeoShape const *ConvertToRoot() const override
+  {
+      return GetUnplacedVolume()->ConvertToRoot(GetName());
+  }
 #endif
 
 #ifdef VECGEOM_GEANT4
-  G4VSolid const *ConvertToGeant4() const override;
+  G4VSolid const *ConvertToGeant4() const override
+  {
+    return GetUnplacedVolume()->ConvertToGeant4(GetName());
+  }
 #endif
 #endif // VECCORE_CUDA
 };
