@@ -1,6 +1,6 @@
 #include "VecGeom/volumes/LogicalVolume.h"
 #include "VecGeom/volumes/Box.h"
-#include "VecGeomBenchmark/Benchmarker.h"
+#include "VecGeomTest/Benchmarker.h"
 #include "VecGeom/volumes/kernel/BoxImplementation.h"
 #include "VecGeom/management/GeoManager.h"
 #include "ArgParser.h"
