@@ -8,7 +8,9 @@
 #include "VecGeom/navigation/NavigationState.h"
 #include "VecGeom/volumes/PlacedVolume.h"
 #include "VecGeom/volumes/LogicalVolume.h"
-#include "VecGeom/management/RootGeoManager.h"
+
+#include "VecGeomTest/RootGeoManager.h"
+
 #include "VecGeom/management/GeoManager.h"
 #include "VecGeom/base/Stopwatch.h"
 #include "VecGeom/navigation/NewSimpleNavigator.h"
@@ -37,7 +39,7 @@
 #include "G4Navigator.hh"
 #include "G4VPhysicalVolume.hh"
 #include "G4ThreeVector.hh"
-#include "VecGeom/management/G4GeoManager.h"
+#include "VecGeomTest/G4GeoManager.h"
 #endif
 
 #include <iostream>
