@@ -1,7 +1,8 @@
 #ifndef LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_VECGEOM_MASKEDASSIGN_H
 #define LLVM_CLANG_TOOLS_EXTRA_CLANG_TIDY_VECGEOM_MASKEDASSIGN_H
 
-#include "ClangTidy.h"
+#include <clang-tidy/ClangTidy.h>
+#include <clang-tidy/ClangTidyCheck.h>
 
 namespace clang {
 namespace tidy {
