@@ -13,7 +13,7 @@
 #include "VecGeom/volumes/utilities/VolumeUtilities.h"
 
 #ifdef VECGEOM_ROOT
-#include "utilities/Visualizer.h"
+#include "VecGeomTest/Visualizer.h"
 #include "TPolyMarker3D.h"
 #include "TPolyLine3D.h"
 #include "VecGeom/volumes/Box.h"
