@@ -1,6 +1,6 @@
 /// \file VisualizeParallelepiped.h
 /// \author: Mihaela Gheata (mihaela.gheata@cern.ch)
-#include "utilities/Visualizer.h"
+#include "VecGeomTest/Visualizer.h"
 #include "VecGeom/volumes/utilities/VolumeUtilities.h"
 #include "TPolyMarker3D.h"
 #include "VecGeom/base/Vector3D.h"
